@@ -36,8 +36,9 @@
 #' van Buuren, S. (2018). \emph{Flexible imputation of missing data} (2nd ed.). Chapman & Hall.
 #'
 #' @return
-#' Returns an object of class \code{na.auxiliary}, which is a list with following entries: function call (\code{call}),
-#' matrix or data frame specified in \code{x} (\code{data}), specification of function arguments (\code{args}), and
+#' Returns an object of class \code{misty.object}, which is a list with following entries:
+#' function call (\code{call}), type of analysis \code{type}, matrix or data frame specified in
+#' \code{x} (\code{data}), specification of function arguments (\code{args}), and
 #' list with results (\code{result}).
 #'
 #' @export
@@ -46,7 +47,7 @@
 #' dat <- data.frame(x1 = c(1, NA, 2, 5, 3, NA, 5, 2),
 #'                   x2 = c(4, 2, 5, 1, 5, 3, 4, 5),
 #'                   x3 = c(NA, 3, 2, 4, 5, 6, NA, 2),
-#'                   x4 = c(5, 6, 3, NA, NA, 4, 6, NA), stringsAsFactors = FALSE)
+#'                   x4 = c(5, 6, 3, NA, NA, 4, 6, NA))
 #'
 #' # Auxiliary variables
 #' na.auxiliary(dat)
@@ -205,7 +206,7 @@ na.auxiliary <- function(x, tri = c("both", "lower", "upper"), weighted = TRUE,
 
   #......
   # Check input 'check'
-  if (!isTRUE(isTRUE(check) || !isTRUE(check))) {
+  if (!is.logical(check)) {
 
     stop("Please specify TRUE or FALSE for the argument 'check'.", call. = FALSE)
 
@@ -234,7 +235,7 @@ na.auxiliary <- function(x, tri = c("both", "lower", "upper"), weighted = TRUE,
 
     #......
     # Check input 'weighted'
-    if (!isTRUE(isTRUE(weighted) | !isTRUE(weighted))) {
+    if (!is.logical(weighted)) {
 
       stop("Please specify TRUE or FALSE for the argument 'weighted'.", call. = FALSE)
 
@@ -242,7 +243,7 @@ na.auxiliary <- function(x, tri = c("both", "lower", "upper"), weighted = TRUE,
 
     #......
     # Check input 'correct'
-    if (!isTRUE(isTRUE(correct) | !isTRUE(correct))) {
+    if (!is.logical(correct)) {
 
       stop("Please specify TRUE or FALSE for the argument 'correct'.", call. = FALSE)
 
@@ -258,7 +259,7 @@ na.auxiliary <- function(x, tri = c("both", "lower", "upper"), weighted = TRUE,
 
     #......
     # Check input 'output'
-    if (!isTRUE(isTRUE(output) | !isTRUE(output))) {
+    if (!is.logical(output)) {
 
       stop("Please specify TRUE or FALSE for the argument 'output'.", call. = FALSE)
 
@@ -352,7 +353,7 @@ na.auxiliary <- function(x, tri = c("both", "lower", "upper"), weighted = TRUE,
                              as.na = as.na, check = check, output = output),
                  result = list(cor = cor.mat, d = d.mat))
 
-  class(object) <- "square.matrix"
+  class(object) <- "misty.object"
 
   ####################################################################################
   # Output
